/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").
 * You may not use this file except in compliance with the License.
 *
 * See LICENSE.txt included in this distribution for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at LICENSE.txt.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

/*
 * Copyright 2007 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */
package org.opensolaris.opengrok.history;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import org.opensolaris.opengrok.configuration.RuntimeEnvironment;

/**
 * HistoryParser that use the Lucene index to generate the history log.
 * (Please note that SCM systems that supports changesets consisting of
 * multiple files should implement their own HistoryParser!)
 *
 * @author Trond Norbye
 */
public class DirectoryHistoryParser implements HistoryParser {

    public History parse(File file, Repository repos) throws HistoryException {
        try {
            return parseFile(file);
        } catch (IOException ioe) {
            throw new HistoryException(ioe);
        }
    }

    private History parseFile(File file) throws IOException {
        RuntimeEnvironment env = RuntimeEnvironment.getInstance();
        String filename = file.getCanonicalPath().substring(env.getSourceRootPath().length());
        HistoryReader hr = new DirectoryHistoryReader(filename);
        
        ArrayList<HistoryEntry> entries = new ArrayList<HistoryEntry>();
        while (hr.next()) {
            HistoryEntry ent = new HistoryEntry(
                hr.getRevision(), hr.getDate(), hr.getAuthor(),
                hr.getComment(), hr.isActive());
            ent.setFiles(hr.getFiles());
            entries.add(ent);
        }

        History history = new History();
        history.setHistoryEntries(entries);
        hr.close();
        return history;
    }

    public Annotation annotate(File file, String revision,
                               Repository repository) {
        return null;
    }

    public boolean isCacheable() {
        return false;
    }
}
